@@ -10,8 +10,11 @@ NULL
 
 # crayon styles -----------------------------------------------------------------------------------------
 
-copyright_style <- crayon::yellow$bold
-legal_note_style <- crayon::blue$bold$underline
+#' crayon styles to use
+#' @importFrom  crayon combine_styles
+#' @noRd
+copyright_style <- crayon::combine_styles('bold', 'yellow')
+legal_note_style <- crayon::combine_styles('blue', 'bold', 'underline')
 
 
 # swiss knives ------------------------------------------------------------------------------------------
@@ -185,7 +188,12 @@ main_test_battery <- function(test_object, ...) {
   # units in temperature and timestamp: ONLY IN DATA, NOT STATIONS
   if (!is.null(args$temperature)) {
     testthat::expect_s3_class(rlang::eval_tidy(args$temperature, data = test_object), 'units')
-    testthat::expect_identical(units(rlang::eval_tidy(args$temperature, data = test_object))$numerator, "\u00B0C")
+    # testthat::expect_identical(units(rlang::eval_tidy(args$temperature, data = test_object))$numerator, "\u00B0C")
+    # The commented test above doesn't work in debian-clang latin-1 CRAN tests, so we test then that it gives
+    # the symbol unit or the text unit:
+    testthat::expect_true(
+      units(rlang::eval_tidy(args$temperature, data = test_object))$numerator %in% c("\u00B0C", "degree_Celsius")
+    )
     testthat::expect_s3_class(test_object$timestamp, 'POSIXct')
     testthat::expect_false(all(is.na(test_object$timestamp)))
   }
@@ -199,7 +207,7 @@ unnest_debug <- function(x, ...) {
 
   if (inherits(x, 'list')) {
     stop(glue::glue(
-      "Something went wrong, no data.frame returned, but a list with the following names {names(x)} and the following contents {glue::glue_collapse(x, sep = '\n'}"
+      "Something went wrong, no data.frame returned, but a list with the following names {names(x)} and the following contents {glue::glue_collapse(x, sep = '\n')}"
     ))
   }
 
