@@ -35,7 +35,7 @@ test_that("meteocat get info works", {
 test_that("meteocat instant works", {
   # all stations
   api_options <- meteocat_options('instant', api_key = keyring::key_get('meteocat'))
-  test_object <- suppressMessages(get_meteo_from('meteocat', api_options))
+  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   expected_names <- c(
     "timestamp", "service", "station_id", "station_name", "station_province", "altitude",
     "temperature",
@@ -62,7 +62,7 @@ test_that("meteocat hourly works", {
   api_options <- meteocat_options(
     'hourly', start_date = as.Date('2021-04-25'), api_key = keyring::key_get('meteocat')
   )
-  test_object <- suppressMessages(get_meteo_from('meteocat', api_options))
+  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   expected_names <- c(
     "timestamp", "service", "station_id", "station_name", "station_province", "altitude",
     "temperature",
@@ -77,7 +77,7 @@ test_that("meteocat hourly works", {
   # some stations
   stations_to_check <- test_object[['station_id']][1:3]
   api_options$stations <- stations_to_check
-  test_object <- suppressMessages(get_meteo_from('meteocat', api_options))
+  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   main_test_battery(
     test_object, service = 'meteocat', expected_names = expected_names, temperature = temperature,
     stations_to_check = stations_to_check
@@ -89,7 +89,7 @@ test_that("meteocat daily works", {
   api_options <- meteocat_options(
     'daily', start_date = as.Date('2021-04-25'), api_key = keyring::key_get('meteocat')
   )
-  test_object <- suppressMessages(get_meteo_from('meteocat', api_options))
+  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   expected_names <- c(
     "timestamp", "service", "station_id", "station_name", "station_province", "altitude",
     "mean_temperature", "min_temperature", 'max_temperature',
@@ -105,7 +105,7 @@ test_that("meteocat daily works", {
   # some stations
   stations_to_check <- test_object[['station_id']][1:3]
   api_options$stations <- stations_to_check
-  test_object <- suppressMessages(get_meteo_from('meteocat', api_options))
+  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   main_test_battery(
     test_object, service = 'meteocat', expected_names = expected_names, temperature = mean_temperature,
     stations_to_check = stations_to_check
@@ -117,7 +117,7 @@ test_that("meteocat monthly works", {
   api_options <- meteocat_options(
     'monthly', start_date = as.Date('2020-04-25'), api_key = keyring::key_get('meteocat')
   )
-  test_object <- suppressMessages(get_meteo_from('meteocat', api_options))
+  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   expected_names <- c(
     "timestamp", "service", "station_id", "station_name", "station_province", "altitude",
     "mean_temperature",
@@ -137,7 +137,7 @@ test_that("meteocat monthly works", {
   # some stations
   stations_to_check <- unique(test_object[['station_id']])[1:3]
   api_options$stations <- stations_to_check
-  test_object <- suppressMessages(get_meteo_from('meteocat', api_options))
+  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   main_test_battery(
     test_object, service = 'meteocat', expected_names = expected_names, temperature = mean_temperature,
     stations_to_check = stations_to_check
@@ -149,7 +149,7 @@ test_that("meteocat yearly works", {
   api_options <- meteocat_options(
     'yearly', start_date = as.Date('2020-04-25'), api_key = keyring::key_get('meteocat')
   )
-  test_object <- suppressMessages(get_meteo_from('meteocat', api_options))
+  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   expected_names <- c(
     "timestamp", "service", "station_id", "station_name", "station_province", "altitude",
     "mean_temperature",
@@ -169,7 +169,7 @@ test_that("meteocat yearly works", {
   # some stations
   stations_to_check <- unique(test_object[['station_id']])[1:3]
   api_options$stations <- stations_to_check
-  test_object <- suppressMessages(get_meteo_from('meteocat', api_options))
+  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   main_test_battery(
     test_object, service = 'meteocat', expected_names = expected_names, temperature = mean_temperature,
     stations_to_check = stations_to_check
@@ -179,7 +179,6 @@ test_that("meteocat yearly works", {
 test_that("meteocat API errors, messages, warnings are correctly raised", {
   # copyright message
   api_options <- meteocat_options(api_key = keyring::key_get('meteocat'))
-  expect_message(get_meteo_from('meteocat', api_options), 'meteo.cat')
   # invalid key
   api_options <- meteocat_options(api_key = 'tururu')
   expect_error(get_meteo_from('meteocat', api_options), "Invalid API Key")
